<?php

namespace Lavalite\Sale\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Lavalite\Sale\Interfaces\SaleRepositoryInterface;

class SalePublicController extends BaseController
{
    // use SaleWorkflow;

    /**
     * Constructor.
     *
     * @param type \Lavalite\Sale\Interfaces\SaleRepositoryInterface $sale
     *
     * @return type
     */
    public function __construct(SaleRepositoryInterface $sale)
    {
        $this->repository = $sale;
        parent::__construct();
    }

    /**
     * Show sale's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $sales = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$sale::$sale.names'))
            ->view('$sale::public.sale.index')
            ->data(compact('$sales'))
            ->output();
    }

    /**
     * Show sale's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $sales = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$sale::$sale.names'))
            ->view('$sale::public.sale.index')
            ->data(compact('$sales'))
            ->output();
    }

    /**
     * Show sale.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $sale = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$sale->name . trans('$sale::$sale.name'))
            ->view('$sale::public.sale.show')
            ->data(compact('$sale'))
            ->output();
    }

}
